Learn R Programming

TrumpetPlots (version 0.0.1.1)

powerCurves: Power Curves for Trumpet Plots

Description

This function generates curves indicating statistical power in Trumpet plots

Usage

powerCurves(threshold = 0.8, N = 4e+05, alpha = 5e-08, Nfreq = 500)

Value

A data frame with the power estimated for each allele frequency and effect size, given a: Statistical power threshold, significance threshold (alpha value), and sample size

Arguments

threshold

user-specified power level

N

sample size

alpha

significance threshold

Nfreq

Number of allele frequency data points generated to calculate the power curves

Examples

Run this code
powerCurves(threshold = 0.8, N=400000, alpha = 5e-8)

Run the code above in your browser using DataLab