A data frame with the power estimated for each allele frequency and effect size, given a: Statistical power threshold, significance threshold (alpha value), and sample size
Arguments
threshold
user-specified power level
N
sample size
alpha
significance threshold
Nfreq
Number of allele frequency data points generated to calculate the power curves